# Autogenerated constants for Rain gauge service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_RAIN_GAUGE = const(0x13734c95)
JD_RAIN_GAUGE_REG_PRECIPITATION = const(JD_REG_READING)
JD_RAIN_GAUGE_REG_PRECIPITATION_PRECISION = const(JD_REG_READING_RESOLUTION)
JD_RAIN_GAUGE_PACK_FORMATS = {
    JD_RAIN_GAUGE_REG_PRECIPITATION: "u16.16",
    JD_RAIN_GAUGE_REG_PRECIPITATION_PRECISION: "u16.16"
}
