# Autogenerated constants for Compass service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_COMPASS = const(0x15b7b9bf)
JD_COMPASS_REG_HEADING = const(JD_REG_READING)
JD_COMPASS_REG_ENABLED = const(JD_REG_INTENSITY)
JD_COMPASS_REG_HEADING_ERROR = const(JD_REG_READING_ERROR)
JD_COMPASS_CMD_CALIBRATE = const(JD_CMD_CALIBRATE)
JD_COMPASS_PACK_FORMATS = {
    JD_COMPASS_REG_HEADING: "u16.16",
    JD_COMPASS_REG_ENABLED: "u8",
    JD_COMPASS_REG_HEADING_ERROR: "u16.16"
}
