# Autogenerated constants for Flex service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_FLEX = const(0x1f47c6c6)
JD_FLEX_REG_BENDING = const(JD_REG_READING)
JD_FLEX_REG_LENGTH = const(0x180)
JD_FLEX_PACK_FORMATS = {
    JD_FLEX_REG_BENDING: "i1.15",
    JD_FLEX_REG_LENGTH: "u16"
}
