# Autogenerated constants for Pressure Button service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_PRESSURE_BUTTON = const(0x281740c3)
JD_PRESSURE_BUTTON_REG_THRESHOLD = const(JD_REG_ACTIVE_THRESHOLD)
JD_PRESSURE_BUTTON_PACK_FORMATS = {
    JD_PRESSURE_BUTTON_REG_THRESHOLD: "u0.16"
}
