# Autogenerated constants for Accelerometer service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_ACCELEROMETER = const(0x1f140409)
JD_ACCELEROMETER_REG_FORCES = const(JD_REG_READING)
JD_ACCELEROMETER_REG_FORCES_ERROR = const(JD_REG_READING_ERROR)
JD_ACCELEROMETER_REG_MAX_FORCE = const(JD_REG_READING_RANGE)
JD_ACCELEROMETER_REG_MAX_FORCES_SUPPORTED = const(JD_REG_SUPPORTED_RANGES)
JD_ACCELEROMETER_EV_TILT_UP = const(0x81)
JD_ACCELEROMETER_EV_TILT_DOWN = const(0x82)
JD_ACCELEROMETER_EV_TILT_LEFT = const(0x83)
JD_ACCELEROMETER_EV_TILT_RIGHT = const(0x84)
JD_ACCELEROMETER_EV_FACE_UP = const(0x85)
JD_ACCELEROMETER_EV_FACE_DOWN = const(0x86)
JD_ACCELEROMETER_EV_FREEFALL = const(0x87)
JD_ACCELEROMETER_EV_SHAKE = const(0x8b)
JD_ACCELEROMETER_EV_FORCE_2G = const(0x8c)
JD_ACCELEROMETER_EV_FORCE_3G = const(0x88)
JD_ACCELEROMETER_EV_FORCE_6G = const(0x89)
JD_ACCELEROMETER_EV_FORCE_8G = const(0x8a)
JD_ACCELEROMETER_PACK_FORMATS = {
    JD_ACCELEROMETER_REG_FORCES: "i12.20 i12.20 i12.20",
    JD_ACCELEROMETER_REG_FORCES_ERROR: "u12.20",
    JD_ACCELEROMETER_REG_MAX_FORCE: "u12.20",
    JD_ACCELEROMETER_REG_MAX_FORCES_SUPPORTED: "r: u12.20"
}
