# Autogenerated constants for Motion service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_MOTION = const(0x1179a749)


class MotionVariant(IntEnum):
    PIR = const(0x1)


JD_MOTION_REG_MOVING = const(JD_REG_READING)
JD_MOTION_REG_MAX_DISTANCE = const(0x180)
JD_MOTION_REG_ANGLE = const(0x181)
JD_MOTION_REG_VARIANT = const(JD_REG_VARIANT)
JD_MOTION_EV_MOVEMENT = const(JD_EV_ACTIVE)
JD_MOTION_PACK_FORMATS = {
    JD_MOTION_REG_MOVING: "u8",
    JD_MOTION_REG_MAX_DISTANCE: "u16.16",
    JD_MOTION_REG_ANGLE: "u16",
    JD_MOTION_REG_VARIANT: "u8"
}
