# Autogenerated constants for Rotary encoder service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_ROTARY_ENCODER = const(0x10fa29c9)
JD_ROTARY_ENCODER_REG_POSITION = const(JD_REG_READING)
JD_ROTARY_ENCODER_REG_CLICKS_PER_TURN = const(0x180)
JD_ROTARY_ENCODER_REG_CLICKER = const(0x181)
JD_ROTARY_ENCODER_PACK_FORMATS = {
    JD_ROTARY_ENCODER_REG_POSITION: "i32",
    JD_ROTARY_ENCODER_REG_CLICKS_PER_TURN: "u16",
    JD_ROTARY_ENCODER_REG_CLICKER: "u8"
}
