# Autogenerated constants for Microphone service
from jacdac.constants import *
JD_SERVICE_CLASS_MICROPHONE = const(0x113dac86)
JD_MICROPHONE_CMD_SAMPLE = const(0x81)
JD_MICROPHONE_REG_SAMPLING_PERIOD = const(0x80)
JD_MICROPHONE_PACK_FORMATS = {
    JD_MICROPHONE_CMD_SAMPLE: "b[12] u32",
    JD_MICROPHONE_REG_SAMPLING_PERIOD: "u32"
}
