# Autogenerated constants for Dimmer service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_DIMMER = const(0x1fb02645)


class DimmerVariant(IntEnum):
    LIGHT = const(0x1)
    FAN = const(0x2)
    PUMP = const(0x3)


JD_DIMMER_REG_INTENSITY = const(JD_REG_INTENSITY)
JD_DIMMER_REG_VARIANT = const(JD_REG_VARIANT)
JD_DIMMER_PACK_FORMATS = {
    JD_DIMMER_REG_INTENSITY: "u0.16",
    JD_DIMMER_REG_VARIANT: "u8"
}
