# Autogenerated constants for Capacitive Button service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_CAPACITIVE_BUTTON = const(0x2865adc9)
JD_CAPACITIVE_BUTTON_REG_THRESHOLD = const(JD_REG_ACTIVE_THRESHOLD)
JD_CAPACITIVE_BUTTON_CMD_CALIBRATE = const(JD_CMD_CALIBRATE)
JD_CAPACITIVE_BUTTON_PACK_FORMATS = {
    JD_CAPACITIVE_BUTTON_REG_THRESHOLD: "u0.16"
}
