# Autogenerated constants for Power supply service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_POWER_SUPPLY = const(0x1f40375f)
JD_POWER_SUPPLY_REG_ENABLED = const(JD_REG_INTENSITY)
JD_POWER_SUPPLY_REG_OUTPUT_VOLTAGE = const(JD_REG_VALUE)
JD_POWER_SUPPLY_REG_MINIMUM_VOLTAGE = const(JD_REG_MIN_VALUE)
JD_POWER_SUPPLY_REG_MAXIMUM_VOLTAGE = const(JD_REG_MAX_VALUE)
JD_POWER_SUPPLY_PACK_FORMATS = {
    JD_POWER_SUPPLY_REG_ENABLED: "u8",
    JD_POWER_SUPPLY_REG_OUTPUT_VOLTAGE: "f64",
    JD_POWER_SUPPLY_REG_MINIMUM_VOLTAGE: "f64",
    JD_POWER_SUPPLY_REG_MAXIMUM_VOLTAGE: "f64"
}
