# Autogenerated constants for Braille display service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_BRAILLE_DISPLAY = const(0x13bfb7cc)
JD_BRAILLE_DISPLAY_REG_ENABLED = const(JD_REG_INTENSITY)
JD_BRAILLE_DISPLAY_REG_PATTERNS = const(JD_REG_VALUE)
JD_BRAILLE_DISPLAY_REG_LENGTH = const(0x181)
JD_BRAILLE_DISPLAY_PACK_FORMATS = {
    JD_BRAILLE_DISPLAY_REG_ENABLED: "u8",
    JD_BRAILLE_DISPLAY_REG_PATTERNS: "s",
    JD_BRAILLE_DISPLAY_REG_LENGTH: "u8"
}
