# Autogenerated constants for Vibration motor service
from jacdac.constants import *
JD_SERVICE_CLASS_VIBRATION_MOTOR = const(0x183fc4a2)
JD_VIBRATION_MOTOR_CMD_VIBRATE = const(0x80)
JD_VIBRATION_MOTOR_PACK_FORMATS = {
    JD_VIBRATION_MOTOR_CMD_VIBRATE: "r: u8 u0.8"
}
