# Autogenerated file. Do not edit.
from jacdac.bus import Bus, Client
from .constants import *



class TcpClient(Client):
    """
    Data transfer over TCP/IP and TLS stream sockets.
    Implements a client for the `TCP <https://microsoft.github.io/jacdac-docs/services/tcp>`_ service.

    """

    def __init__(self, bus: Bus, role: str) -> None:
        super().__init__(bus, JD_SERVICE_CLASS_TCP, JD_TCP_PACK_FORMATS, role)


    
