# Autogenerated constants for Water level service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_WATER_LEVEL = const(0x147b62ed)


class WaterLevelVariant(IntEnum):
    RESISTIVE = const(0x1)
    CONTACT_PHOTO_ELECTRIC = const(0x2)
    NON_CONTACT_PHOTO_ELECTRIC = const(0x3)


JD_WATER_LEVEL_REG_LEVEL = const(JD_REG_READING)
JD_WATER_LEVEL_REG_LEVEL_ERROR = const(JD_REG_READING_ERROR)
JD_WATER_LEVEL_REG_VARIANT = const(JD_REG_VARIANT)
JD_WATER_LEVEL_PACK_FORMATS = {
    JD_WATER_LEVEL_REG_LEVEL: "u0.16",
    JD_WATER_LEVEL_REG_LEVEL_ERROR: "u0.16",
    JD_WATER_LEVEL_REG_VARIANT: "u8"
}
