# Autogenerated constants for Traffic Light service
from jacdac.constants import *
JD_SERVICE_CLASS_TRAFFIC_LIGHT = const(0x15c38d9b)
JD_TRAFFIC_LIGHT_REG_RED = const(0x80)
JD_TRAFFIC_LIGHT_REG_YELLOW = const(0x81)
JD_TRAFFIC_LIGHT_REG_GREEN = const(0x82)
JD_TRAFFIC_LIGHT_PACK_FORMATS = {
    JD_TRAFFIC_LIGHT_REG_RED: "u8",
    JD_TRAFFIC_LIGHT_REG_YELLOW: "u8",
    JD_TRAFFIC_LIGHT_REG_GREEN: "u8"
}
