# Autogenerated constants for Bridge service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_BRIDGE = const(0x1fe5b46f)
JD_BRIDGE_REG_ENABLED = const(JD_REG_INTENSITY)
JD_BRIDGE_PACK_FORMATS = {
    JD_BRIDGE_REG_ENABLED: "u8"
}
