# Autogenerated constants for Air Quality Index service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_AIR_QUALITY_INDEX = const(0x14ac6ed6)
JD_AIR_QUALITY_INDEX_REG_AQI_INDEX = const(JD_REG_READING)
JD_AIR_QUALITY_INDEX_REG_AQI_INDEX_ERROR = const(JD_REG_READING_ERROR)
JD_AIR_QUALITY_INDEX_REG_MIN_AQI_INDEX = const(JD_REG_MIN_READING)
JD_AIR_QUALITY_INDEX_REG_MAX_AQI_INDEX = const(JD_REG_MAX_READING)
JD_AIR_QUALITY_INDEX_PACK_FORMATS = {
    JD_AIR_QUALITY_INDEX_REG_AQI_INDEX: "u16.16",
    JD_AIR_QUALITY_INDEX_REG_AQI_INDEX_ERROR: "u16.16",
    JD_AIR_QUALITY_INDEX_REG_MIN_AQI_INDEX: "u16.16",
    JD_AIR_QUALITY_INDEX_REG_MAX_AQI_INDEX: "u16.16"
}
