# Autogenerated constants for Logger service
from enum import IntEnum
from jacdac.constants import *
JD_SERVICE_CLASS_LOGGER = const(0x12dc1fca)


class LoggerPriority(IntEnum):
    DEBUG = const(0x0)
    LOG = const(0x1)
    WARNING = const(0x2)
    ERROR = const(0x3)
    SILENT = const(0x4)


JD_LOGGER_REG_MIN_PRIORITY = const(0x80)
JD_LOGGER_CMD_DEBUG = const(0x80)
JD_LOGGER_CMD_LOG = const(0x81)
JD_LOGGER_CMD_WARN = const(0x82)
JD_LOGGER_CMD_ERROR = const(0x83)
JD_LOGGER_PACK_FORMATS = {
    JD_LOGGER_REG_MIN_PRIORITY: "u8",
    JD_LOGGER_CMD_DEBUG: "s",
    JD_LOGGER_CMD_LOG: "s",
    JD_LOGGER_CMD_WARN: "s",
    JD_LOGGER_CMD_ERROR: "s"
}
