# Autogenerated constants for HID Joystick service
from jacdac.constants import *
JD_SERVICE_CLASS_HID_JOYSTICK = const(0x1a112155)
JD_HID_JOYSTICK_REG_BUTTON_COUNT = const(0x180)
JD_HID_JOYSTICK_REG_BUTTONS_ANALOG = const(0x181)
JD_HID_JOYSTICK_REG_AXIS_COUNT = const(0x182)
JD_HID_JOYSTICK_CMD_SET_BUTTONS = const(0x80)
JD_HID_JOYSTICK_CMD_SET_AXIS = const(0x81)
JD_HID_JOYSTICK_PACK_FORMATS = {
    JD_HID_JOYSTICK_REG_BUTTON_COUNT: "u8",
    JD_HID_JOYSTICK_REG_BUTTONS_ANALOG: "u32",
    JD_HID_JOYSTICK_REG_AXIS_COUNT: "u8",
    JD_HID_JOYSTICK_CMD_SET_BUTTONS: "r: u0.8",
    JD_HID_JOYSTICK_CMD_SET_AXIS: "r: i1.15"
}
