# Autogenerated constants for Sound level service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_SOUND_LEVEL = const(0x14ad1a5d)
JD_SOUND_LEVEL_REG_SOUND_LEVEL = const(JD_REG_READING)
JD_SOUND_LEVEL_REG_ENABLED = const(JD_REG_INTENSITY)
JD_SOUND_LEVEL_PACK_FORMATS = {
    JD_SOUND_LEVEL_REG_SOUND_LEVEL: "u0.16",
    JD_SOUND_LEVEL_REG_ENABLED: "u8"
}
