# Autogenerated constants for Acidity service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_ACIDITY = const(0x1e9778c5)
JD_ACIDITY_REG_ACIDITY = const(JD_REG_READING)
JD_ACIDITY_REG_ACIDITY_ERROR = const(JD_REG_READING_ERROR)
JD_ACIDITY_REG_MIN_ACIDITY = const(JD_REG_MIN_READING)
JD_ACIDITY_REG_MAX_HUMIDITY = const(JD_REG_MAX_READING)
JD_ACIDITY_PACK_FORMATS = {
    JD_ACIDITY_REG_ACIDITY: "u4.12",
    JD_ACIDITY_REG_ACIDITY_ERROR: "u4.12",
    JD_ACIDITY_REG_MIN_ACIDITY: "u4.12",
    JD_ACIDITY_REG_MAX_HUMIDITY: "u4.12"
}
