# Autogenerated constants for Wind direction service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_WIND_DIRECTION = const(0x186be92b)
JD_WIND_DIRECTION_REG_WIND_DIRECTION = const(JD_REG_READING)
JD_WIND_DIRECTION_REG_WIND_DIRECTION_ERROR = const(JD_REG_READING_ERROR)
JD_WIND_DIRECTION_PACK_FORMATS = {
    JD_WIND_DIRECTION_REG_WIND_DIRECTION: "u16",
    JD_WIND_DIRECTION_REG_WIND_DIRECTION_ERROR: "u16"
}
