# Autogenerated constants for DC Current Measurement service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_D_CCURRENT_MEASUREMENT = const(0x1912c8ae)
JD_D_CCURRENT_MEASUREMENT_REG_MEASUREMENT_NAME = const(0x182)
JD_D_CCURRENT_MEASUREMENT_REG_MEASUREMENT = const(JD_REG_READING)
JD_D_CCURRENT_MEASUREMENT_PACK_FORMATS = {
    JD_D_CCURRENT_MEASUREMENT_REG_MEASUREMENT_NAME: "s",
    JD_D_CCURRENT_MEASUREMENT_REG_MEASUREMENT: "f64"
}
