# Autogenerated constants for Air Pressure service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_AIR_PRESSURE = const(0x1e117cea)
JD_AIR_PRESSURE_REG_PRESSURE = const(JD_REG_READING)
JD_AIR_PRESSURE_REG_PRESSURE_ERROR = const(JD_REG_READING_ERROR)
JD_AIR_PRESSURE_PACK_FORMATS = {
    JD_AIR_PRESSURE_REG_PRESSURE: "u22.10",
    JD_AIR_PRESSURE_REG_PRESSURE_ERROR: "u22.10"
}
