# Autogenerated constants for Wind speed service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_WIND_SPEED = const(0x1b591bbf)
JD_WIND_SPEED_REG_WIND_SPEED = const(JD_REG_READING)
JD_WIND_SPEED_REG_WIND_SPEED_ERROR = const(JD_REG_READING_ERROR)
JD_WIND_SPEED_REG_MAX_WIND_SPEED = const(JD_REG_MAX_READING)
JD_WIND_SPEED_PACK_FORMATS = {
    JD_WIND_SPEED_REG_WIND_SPEED: "u16.16",
    JD_WIND_SPEED_REG_WIND_SPEED_ERROR: "u16.16",
    JD_WIND_SPEED_REG_MAX_WIND_SPEED: "u16.16"
}
