# Autogenerated constants for Humidity service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_HUMIDITY = const(0x16c810b8)
JD_HUMIDITY_REG_HUMIDITY = const(JD_REG_READING)
JD_HUMIDITY_REG_HUMIDITY_ERROR = const(JD_REG_READING_ERROR)
JD_HUMIDITY_REG_MIN_HUMIDITY = const(JD_REG_MIN_READING)
JD_HUMIDITY_REG_MAX_HUMIDITY = const(JD_REG_MAX_READING)
JD_HUMIDITY_PACK_FORMATS = {
    JD_HUMIDITY_REG_HUMIDITY: "u22.10",
    JD_HUMIDITY_REG_HUMIDITY_ERROR: "u22.10",
    JD_HUMIDITY_REG_MIN_HUMIDITY: "u22.10",
    JD_HUMIDITY_REG_MAX_HUMIDITY: "u22.10"
}
