# Autogenerated constants for Pulse Oximeter service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_PULSE_OXIMETER = const(0x10bb4eb6)
JD_PULSE_OXIMETER_REG_OXYGEN = const(JD_REG_READING)
JD_PULSE_OXIMETER_REG_OXYGEN_ERROR = const(JD_REG_READING_ERROR)
JD_PULSE_OXIMETER_PACK_FORMATS = {
    JD_PULSE_OXIMETER_REG_OXYGEN: "u8.8",
    JD_PULSE_OXIMETER_REG_OXYGEN_ERROR: "u8.8"
}
