# Autogenerated constants for Color service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_COLOR = const(0x1630d567)
JD_COLOR_REG_COLOR = const(JD_REG_READING)
JD_COLOR_PACK_FORMATS = {
    JD_COLOR_REG_COLOR: "u0.16 u0.16 u0.16"
}
