# Autogenerated constants for Multitouch service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_MULTITOUCH = const(0x1d112ab5)
JD_MULTITOUCH_REG_CAPACITY = const(JD_REG_READING)
JD_MULTITOUCH_EV_TOUCH = const(JD_EV_ACTIVE)
JD_MULTITOUCH_EV_RELEASE = const(JD_EV_INACTIVE)
JD_MULTITOUCH_EV_TAP = const(0x80)
JD_MULTITOUCH_EV_LONG_PRESS = const(0x81)
JD_MULTITOUCH_EV_SWIPE_POS = const(0x90)
JD_MULTITOUCH_EV_SWIPE_NEG = const(0x91)
JD_MULTITOUCH_PACK_FORMATS = {
    JD_MULTITOUCH_REG_CAPACITY: "r: i16",
    JD_MULTITOUCH_EV_TOUCH: "u8",
    JD_MULTITOUCH_EV_RELEASE: "u8",
    JD_MULTITOUCH_EV_TAP: "u8",
    JD_MULTITOUCH_EV_LONG_PRESS: "u8",
    JD_MULTITOUCH_EV_SWIPE_POS: "u16 u8 u8",
    JD_MULTITOUCH_EV_SWIPE_NEG: "u16 u8 u8"
}
