# Autogenerated constants for Temperature service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_TEMPERATURE = const(0x1421bac7)


class TemperatureVariant(IntEnum):
    OUTDOOR = const(0x1)
    INDOOR = const(0x2)
    BODY = const(0x3)


JD_TEMPERATURE_REG_TEMPERATURE = const(JD_REG_READING)
JD_TEMPERATURE_REG_MIN_TEMPERATURE = const(JD_REG_MIN_READING)
JD_TEMPERATURE_REG_MAX_TEMPERATURE = const(JD_REG_MAX_READING)
JD_TEMPERATURE_REG_TEMPERATURE_ERROR = const(JD_REG_READING_ERROR)
JD_TEMPERATURE_REG_VARIANT = const(JD_REG_VARIANT)
JD_TEMPERATURE_PACK_FORMATS = {
    JD_TEMPERATURE_REG_TEMPERATURE: "i22.10",
    JD_TEMPERATURE_REG_MIN_TEMPERATURE: "i22.10",
    JD_TEMPERATURE_REG_MAX_TEMPERATURE: "i22.10",
    JD_TEMPERATURE_REG_TEMPERATURE_ERROR: "u22.10",
    JD_TEMPERATURE_REG_VARIANT: "u8"
}
