# Autogenerated constants for Jacscript Condition service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_JACSCRIPT_CONDITION = const(0x1196796d)
JD_JACSCRIPT_CONDITION_CMD_SIGNAL = const(0x80)
JD_JACSCRIPT_CONDITION_EV_SIGNALLED = const(JD_EV_CHANGE)
JD_JACSCRIPT_CONDITION_PACK_FORMATS = {

}
