# Autogenerated constants for Illuminance service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_ILLUMINANCE = const(0x1e6ecaf2)
JD_ILLUMINANCE_REG_ILLUMINANCE = const(JD_REG_READING)
JD_ILLUMINANCE_REG_ILLUMINANCE_ERROR = const(JD_REG_READING_ERROR)
JD_ILLUMINANCE_PACK_FORMATS = {
    JD_ILLUMINANCE_REG_ILLUMINANCE: "u22.10",
    JD_ILLUMINANCE_REG_ILLUMINANCE_ERROR: "u22.10"
}
