# Autogenerated constants for bit:radio service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_BIT_RADIO = const(0x1ac986cf)
JD_BIT_RADIO_REG_ENABLED = const(JD_REG_INTENSITY)
JD_BIT_RADIO_REG_GROUP = const(0x80)
JD_BIT_RADIO_REG_TRANSMISSION_POWER = const(0x81)
JD_BIT_RADIO_REG_FREQUENCY_BAND = const(0x82)
JD_BIT_RADIO_CMD_SEND_STRING = const(0x80)
JD_BIT_RADIO_CMD_SEND_NUMBER = const(0x81)
JD_BIT_RADIO_CMD_SEND_VALUE = const(0x82)
JD_BIT_RADIO_CMD_SEND_BUFFER = const(0x83)
JD_BIT_RADIO_CMD_STRING_RECEIVED = const(0x90)
JD_BIT_RADIO_CMD_NUMBER_RECEIVED = const(0x91)
JD_BIT_RADIO_CMD_BUFFER_RECEIVED = const(0x92)
JD_BIT_RADIO_PACK_FORMATS = {
    JD_BIT_RADIO_REG_ENABLED: "u8",
    JD_BIT_RADIO_REG_GROUP: "u8",
    JD_BIT_RADIO_REG_TRANSMISSION_POWER: "u8",
    JD_BIT_RADIO_REG_FREQUENCY_BAND: "u8",
    JD_BIT_RADIO_CMD_SEND_STRING: "s",
    JD_BIT_RADIO_CMD_SEND_NUMBER: "f64",
    JD_BIT_RADIO_CMD_SEND_VALUE: "f64 s",
    JD_BIT_RADIO_CMD_SEND_BUFFER: "b",
    JD_BIT_RADIO_CMD_STRING_RECEIVED: "u32 u32 i8 b[1] s",
    JD_BIT_RADIO_CMD_NUMBER_RECEIVED: "u32 u32 i8 b[3] f64 s",
    JD_BIT_RADIO_CMD_BUFFER_RECEIVED: "u32 u32 i8 b[1] b"
}
