# Autogenerated constants for Timeseries Aggregator service
from jacdac.constants import *
JD_SERVICE_CLASS_TIMESERIES_AGGREGATOR = const(0x1192bdcc)
JD_TIMESERIES_AGGREGATOR_CMD_CLEAR = const(0x80)
JD_TIMESERIES_AGGREGATOR_CMD_UPDATE = const(0x83)
JD_TIMESERIES_AGGREGATOR_CMD_SET_WINDOW = const(0x84)
JD_TIMESERIES_AGGREGATOR_CMD_SET_UPLOAD = const(0x85)
JD_TIMESERIES_AGGREGATOR_CMD_STORED = const(0x90)
JD_TIMESERIES_AGGREGATOR_REG_NOW = const(0x180)
JD_TIMESERIES_AGGREGATOR_REG_FAST_START = const(0x80)
JD_TIMESERIES_AGGREGATOR_REG_DEFAULT_WINDOW = const(0x81)
JD_TIMESERIES_AGGREGATOR_REG_DEFAULT_UPLOAD = const(0x82)
JD_TIMESERIES_AGGREGATOR_REG_UPLOAD_UNLABELLED = const(0x83)
JD_TIMESERIES_AGGREGATOR_REG_SENSOR_WATCHDOG_PERIOD = const(0x84)
JD_TIMESERIES_AGGREGATOR_PACK_FORMATS = {
    JD_TIMESERIES_AGGREGATOR_CMD_UPDATE: "f64 s",
    JD_TIMESERIES_AGGREGATOR_CMD_SET_WINDOW: "u32 s",
    JD_TIMESERIES_AGGREGATOR_CMD_SET_UPLOAD: "u8 s",
    JD_TIMESERIES_AGGREGATOR_CMD_STORED: "u32 f64 f64 f64 u32 u32 s",
    JD_TIMESERIES_AGGREGATOR_REG_NOW: "u32",
    JD_TIMESERIES_AGGREGATOR_REG_FAST_START: "u8",
    JD_TIMESERIES_AGGREGATOR_REG_DEFAULT_WINDOW: "u32",
    JD_TIMESERIES_AGGREGATOR_REG_DEFAULT_UPLOAD: "u8",
    JD_TIMESERIES_AGGREGATOR_REG_UPLOAD_UNLABELLED: "u8",
    JD_TIMESERIES_AGGREGATOR_REG_SENSOR_WATCHDOG_PERIOD: "u32"
}
