# Autogenerated constants for Sound player service
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_SOUND_PLAYER = const(0x1403d338)
JD_SOUND_PLAYER_REG_VOLUME = const(JD_REG_INTENSITY)
JD_SOUND_PLAYER_CMD_PLAY = const(0x80)
JD_SOUND_PLAYER_CMD_CANCEL = const(0x81)
JD_SOUND_PLAYER_CMD_LIST_SOUNDS = const(0x82)
JD_SOUND_PLAYER_PACK_FORMATS = {
    JD_SOUND_PLAYER_REG_VOLUME: "u0.16",
    JD_SOUND_PLAYER_CMD_PLAY: "s",
    JD_SOUND_PLAYER_CMD_LIST_SOUNDS: "b[12]"
}
