# Autogenerated constants for UV index service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_UV_INDEX = const(0x1f6e0d90)


class UvIndexVariant(IntEnum):
    UVA_UVB = const(0x1)
    VISIBLE_IR = const(0x2)


JD_UV_INDEX_REG_UV_INDEX = const(JD_REG_READING)
JD_UV_INDEX_REG_UV_INDEX_ERROR = const(JD_REG_READING_ERROR)
JD_UV_INDEX_REG_VARIANT = const(JD_REG_VARIANT)
JD_UV_INDEX_PACK_FORMATS = {
    JD_UV_INDEX_REG_UV_INDEX: "u16.16",
    JD_UV_INDEX_REG_UV_INDEX_ERROR: "u16.16",
    JD_UV_INDEX_REG_VARIANT: "u8"
}
